@@ -5,29 +5,27 @@
 #' @param n Number of simulations.
 #' @param model The parametric model type; one of:
 #' \itemize{
-#' \item \code{HR} (default),
-#' \item \code{logistic},
-#' \item \code{neglogistic},
-#' \item \code{dirichlet}.
+#'   \item `HR` (default),
+#'   \item `logistic`,
+#'   \item `neglogistic`,
+#'   \item `dirichlet`.
 #' }
 #' @param d Dimension of the multivariate Pareto
 #' distribution.
-#' @param par Respective parameter for the given \code{model}, that is,
+#' @param par Respective parameter for the given `model`, that is,
 #' \itemize{
-#' \item \eqn{\Gamma}, numeric \eqn{d \times d}{d x d} variogram matrix,
-#' if \code{model = HR}.
-#' \item \eqn{\theta \in (0, 1)}{0 < \theta < 1}, if \code{model = logistic}.
-#' \item \eqn{\theta > 0}, if \code{model = neglogistic}.
-#' \item \eqn{\alpha}, numeric vector of size \code{d} with positive entries,
-#' if \code{model = dirichlet}.
+#'   \item \eGamma, numeric \dxd variogram matrix, if `model = HR`.
+#'   \item \eqn{\theta \in (0, 1)}{0 < \theta < 1}, if `model = logistic`.
+#'   \item \eqn{\theta > 0}, if `model = neglogistic`.
+#'   \item \eqn{\alpha}, numeric vector of size `d` with positive entries, if `model = dirichlet`.
 #' }
 #'
 #' @return
-#' Numeric matrix of size \eqn{n \times d}{n x d} of simulations of the
+#' Numeric \nxd matrix of simulations of the
 #' multivariate Pareto distribution.
 #'
 #' @details
-  #' The simulation follows the algorithm in \insertCite{eng2019;textual}{graphicalExtremes}.
+#' The simulation follows the algorithm in \insertCite{eng2019;textual}{graphicalExtremes}.
 #' For details on the parameters of the Huesler--Reiss, logistic
 #' and negative logistic distributions see \insertCite{dom2016;textual}{graphicalExtremes}, and for the Dirichlet
 #' distribution see \insertCite{coles1991modelling;textual}{graphicalExtremes}.
@@ -36,10 +34,12 @@
 #' ## A 4-dimensional HR distribution
 #' n <- 10
 #' d <- 4
-#' G <-  cbind(c(0, 1.5, 1.5, 2),
-#'             c(1.5, 0, 2, 1.5),
-#'             c(1.5, 2, 0, 1.5),
-#'             c(2, 1.5, 1.5, 0))
+#' G <- cbind(
+#'   c(0, 1.5, 1.5, 2),
+#'   c(1.5, 0, 2, 1.5),
+#'   c(1.5, 2, 0, 1.5),
+#'   c(2, 1.5, 1.5, 0)
+#' )
 #'
 #' rmpareto(n, "HR", d = d, par = G)
 #'
@@ -60,63 +60,63 @@
 #' d <- 4
 #' alpha <- c(.8, 1, .5, 2)
 #' rmpareto(n, "dirichlet", d, par = alpha)
-#'
 #' @references
 #'  \insertAllCited{}
 #'
 #' @export
-rmpareto <- function(n,
-                     model = c("HR", "logistic", "neglogistic", "dirichlet")[1],
-                     d, par) {
-
-  # methods
-  model_nms <- c("HR", "logistic", "neglogistic", "dirichlet")
+rmpareto <- function(
+  n,
+  model = c("HR", "logistic", "neglogistic", "dirichlet"),
+  d,
+  par
+){
+  model <- match.arg(model)
 
   # check arguments ####
-  if (d != round(d) | d < 1){
+  if (d != round(d) | d < 1) {
     stop("The argument d must be a positive integer.")
   }
 
-  if (n != round(n) | n < 1){
+  if (n != round(n) | n < 1) {
     stop("The argument n must be a positive integer.")
   }
 
-  if (!(model %in% model_nms)){
-    stop(paste("The model must be one of", model_nms))
-  }
-
   if (model == "HR") {
-    if (!is.matrix(par)){
+    if (!is.matrix(par)) {
       stop("The argument par must be a matrix, when model = HR.")
     }
 
-    if (NROW(par) != d | NCOL(par) != d){
+    if (NROW(par) != d | NCOL(par) != d) {
       stop("The argument par must be a d x d matrix, when model = HR.")
     }
-
   } else if (model == "logistic") {
-    if (length(par) != 1 | par <= 1e-12 | par >= 1 - 1e-12){
-      stop(paste("The argument par must be scalar between 1e-12 and 1 - 1e-12,",
-                 "when model = logistic."))
+    if (length(par) != 1 | par <= 1e-12 | par >= 1 - 1e-12) {
+      stop(paste(
+        "The argument par must be scalar between 1e-12 and 1 - 1e-12,",
+        "when model = logistic."
+      ))
     }
-
   } else if (model == "neglogistic") {
-    if (par <= 1e-12){
-      stop(paste("The argument par must be scalar greater than 1e-12,",
-                 "when model = neglogistic."))
+    if (par <= 1e-12) {
+      stop(paste(
+        "The argument par must be scalar greater than 1e-12,",
+        "when model = neglogistic."
+      ))
     }
-
   } else if (model == "dirichlet") {
-    if (length(par) != d){
-      stop(paste("The argument par must be a vector with d elements,",
-                 "when model = dirichlet."))
+    if (length(par) != d) {
+      stop(paste(
+        "The argument par must be a vector with d elements,",
+        "when model = dirichlet."
+      ))
     }
 
-    if (any(par <= 1e-12)){
-      stop(paste("The elements of par must be greater than 1e-12,",
-                 "when model = dirichlet."))
+    if (any(par <= 1e-12)) {
+      stop(paste(
+        "The elements of par must be greater than 1e-12,",
+        "when model = dirichlet."
+      ))
     }
-
   }
 
   # prepare arguments ####
@@ -127,55 +127,56 @@ rmpareto <- function(n,
     cov.mat <- Gamma2Sigma(Gamma, k = 1, full = FALSE)
     chol_mat <- matrix(0, d, d)
 
-    result <- tryCatch({
-      chol_mat[-1, -1] <- chol(cov.mat)
-    },
-    error = function(e) {
-      stop(paste("The covariance matrix associated to Gamma",
-                 "cannot be factorized with Cholesky."))
-    })
+    result <- tryCatch(
+      {
+        chol_mat[-1, -1] <- chol(cov.mat)
+      },
+      error = function(e) {
+        stop(paste(
+          "The covariance matrix associated to Gamma",
+          "cannot be factorized with Cholesky."
+        ))
+      }
+    )
 
     # compute trend (matrix where each row is one variable)
-    trend <- t(sapply(1:d, function(k){
-      sapply(1:d, function(j){
+    trend <- t(sapply(1:d, function(k) {
+      sapply(1:d, function(j) {
         Gamma[j, k] / 2
-      }
-      )}))
-
+      })
+    }))
   } else if (model == "logistic") {
     theta <- par
-
   } else if (model == "neglogistic") {
     theta <- par
-
   } else if (model == "dirichlet") {
     alpha <- par
-
   }
 
   # function body ####
   counter <- 0
   res <- numeric(0)
   n.total <- 0
-  while (n.total < n){
+  while (n.total < n) {
     counter <- counter + 1
     shift <- sample(1:d, n, replace = TRUE)
-    for (k in 1:d){
-
+    for (k in 1:d) {
       n.k <- sum(shift == k)
 
-      if (n.k > 0){
+      if (n.k > 0) {
         proc <-
           switch(model,
-                 "HR" =
-                   simu_px_HR(n = n.k, idx = k, d = d, trend = trend[k, ],
-                              chol_mat = chol_mat),
-                 "logistic" =
-                   simu_px_logistic(n = n.k, idx = k, d = d, theta = theta),
-                 "neglogistic" =
-                   simu_px_neglogistic(n = n.k, idx = k, d = d, theta = theta),
-                 "dirichlet" =
-                   simu_px_dirichlet(n = n.k, idx = k, d = d, alpha = alpha)
+            "HR" =
+              simu_px_HR(
+                n = n.k, idx = k, d = d, trend = trend[k, ],
+                chol_mat = chol_mat
+              ),
+            "logistic" =
+              simu_px_logistic(n = n.k, idx = k, d = d, theta = theta),
+            "neglogistic" =
+              simu_px_neglogistic(n = n.k, idx = k, d = d, theta = theta),
+            "dirichlet" =
+              simu_px_dirichlet(n = n.k, idx = k, d = d, alpha = alpha)
           )
 
         if (any(dim(proc) != c(n.k, d))) {
@@ -186,7 +187,6 @@ rmpareto <- function(n,
         idx.sim <- which(apply(proc, 1, max) > 1)
         res <- rbind(res, proc[idx.sim, ])
         n.total <- NROW(res)
-
       }
     }
   }
@@ -204,30 +204,30 @@ rmpareto <- function(n,
 #' @param n Number of simulations.
 #' @param model The parametric model type; one of:
 #' \itemize{
-#' \item \code{HR} (default),
-#' \item \code{logistic},
-#' \item \code{dirichlet}.
+#'   \item `HR` (default),
+#'   \item `logistic`,
+#'   \item `dirichlet`.
 #' }
-#' @param tree Graph object from \code{igraph} package.
+#' @param tree Graph object from `igraph` package.
 #' This object must be a tree, i.e., an
 #' undirected graph that is connected and has no cycles.
-#' @param par Respective parameter for the given \code{model}, that is,
+#' @param par Respective parameter for the given `model`, that is,
 #' \itemize{
-#' \item \eqn{\Gamma}, numeric \eqn{d \times d}{d x d} variogram matrix,
-#' where only the entries corresponding to the edges of the \code{tree} are used,
-#' if \code{model = HR}. Alternatively, can be a vector of
-#' length \eqn{d - 1} containing the entries of the variogram corresponding
-#' to the edges of the given \code{tree}.
-#' \item \eqn{\theta \in (0, 1)}{0 < \theta < 1}, vector of length \eqn{d - 1}
-#' containing the logistic parameters corresponding
-#' to the edges of the given \code{tree}, if \code{model = logistic}.
-#' \item a matrix of size \eqn{(d - 1) \times 2}{(d - 1) x 2}, where the rows
-#' contain the parameters vectors \eqn{\alpha} of size 2 with positve entries
-#' for each of the edges in \code{tree}, if \code{model = dirichlet}.
+#'   \item \eGamma, numeric \dxd variogram matrix,
+#'     where only the entries corresponding to the edges of the `tree` are used,
+#'     if `model = HR`. Alternatively, can be a vector of
+#'     length `d-1` containing the entries of the variogram corresponding
+#'     to the edges of the given `tree`.
+#'   \item \eqn{\theta \in (0, 1)}{0 < \theta < 1}, vector of length `d-1`
+#'     containing the logistic parameters corresponding
+#'     to the edges of the given `tree`, if `model = logistic`.
+#'   \item a matrix of size \eqn{(d - 1) \times 2}{(d - 1) x 2}, where the rows
+#'     contain the parameters vectors \eqn{\alpha} of size 2 with positve entries
+#'     for each of the edges in `tree`, if `model = dirichlet`.
 #' }
 #'
 #' @return
-#' Numeric matrix of size \eqn{n \times d}{n x d} of simulations of the
+#' Numeric \nxd matrix of simulations of the
 #' multivariate Pareto distribution.
 #'
 #' @details
@@ -240,21 +240,22 @@ rmpareto <- function(n,
 #' ## A 4-dimensional HR tree model
 #'
 #' my_tree <- igraph::graph_from_adjacency_matrix(rbind(
-#' c(0, 1, 0, 0),
-#' c(1, 0, 1, 1),
-#' c(0, 1, 0, 0),
-#' c(0, 1, 0, 0)),
-#' mode = "undirected")
+#'   c(0, 1, 0, 0),
+#'   c(1, 0, 1, 1),
+#'   c(0, 1, 0, 0),
+#'   c(0, 1, 0, 0)
+#' ),
+#' mode = "undirected"
+#' )
 #' n <- 10
-#' Gamma_vec <- c(.5,1.4,.8)
+#' Gamma_vec <- c(.5, 1.4, .8)
 #' set.seed(123)
 #' rmpareto_tree(n, "HR", tree = my_tree, par = Gamma_vec)
 #'
 #' ## A 4-dimensional Dirichlet model with asymmetric edge distributions
 #'
-#' alpha = cbind(c(.2, 1, .5), c(1.5, .6, .8))
+#' alpha <- cbind(c(.2, 1, .5), c(1.5, .6, .8))
 #' rmpareto_tree(n, model = "dirichlet", tree = my_tree, par = alpha)
-#'
 #' @references
 #'  \insertAllCited{}
 #'
@@ -267,7 +268,7 @@ rmpareto_tree <- function(n, model = c("HR", "logistic", "dirichlet")[1],
 
   # graph theory objects ####
   # check if it is directed
-  if (igraph::is_directed(tree)){
+  if (igraph::is_directed(tree)) {
     warning("The given tree is directed. Converted to undirected.")
     tree <- igraph::as.undirected(tree)
   }
@@ -282,63 +283,91 @@ rmpareto_tree <- function(n, model = c("HR", "logistic", "dirichlet")[1],
   is_connected <- igraph::is_connected(tree)
   is_tree <- is_connected & (e == d - 1)
 
-  if (!is_tree){
+  if (!is_tree) {
     stop("The given graph is not a tree.")
   }
 
 
   # check arguments ####
-  if (d != round(d) | d < 1){
+  if (d != round(d) | d < 1) {
     stop("The argument d must be a positive integer.")
   }
 
-  if (n != round(n) | n < 1){
+  if (n != round(n) | n < 1) {
     stop("The argument n must be a positive integer.")
   }
 
-  if (!(model %in% model_nms)){
-    stop(paste("The model must be one of", model_nms))
+  if (!(model %in% model_nms)) {
+    stop(paste("The model must be one of ", paste(model_nms, collapse = ", "),
+      ".",
+      sep = ""
+    ))
   }
 
   if (model == "HR") {
-    if (!is.matrix(par)){
-      if (length(par) != (d - 1)){
-        stop(paste("The argument par must be a d x d matrix,",
-                   "or a vector with d - 1 elements, when model = HR."))
+    if (!is.matrix(par)) {
+      if (length(par) != (d - 1)) {
+        stop(paste(
+          "The argument par must be a d x d matrix,",
+          "or a vector with d - 1 elements, when model = HR."
+        ))
       }
     } else {
-      if (NROW(par) != d | NCOL(par) != d){
-        stop(paste("The argument par must be a d x d matrix,",
-                   "or a vector with d elements, when model = HR."))
+      if (NROW(par) != d | NCOL(par) != d) {
+        stop(paste(
+          "The argument par must be a d x d matrix,",
+          "or a vector with d elements, when model = HR."
+        ))
       }
     }
   } else if (model == "logistic") {
-    if (length(par) != 1 | par <= 1e-12 | par >= 1 - 1e-12){
-      stop(paste("The argument par must be scalar between 1e-12 and 1 - 1e-12,",
-                 "when model = logistic."))
+    if (any(par <= 1e-12) | any(par >= 1 - 1e-12)) {
+      stop(paste(
+        "The elements of par must be",
+        "between 1e-12 and 1 - 1e-12,",
+        "when model = logistic."
+      ))
     }
 
-  } else if (model == "dirichlet") {
-    if (NROW(par) != d - 1 | NCOL(par) != 2){
-      stop(paste("The argument par must be a (d-1) x 2 ,",
-                 "when model = dirichlet."))
+    if (length(par) == 1) {
+      par <- rep(par, d - 1)
+      warning(paste(
+        "The argument par was a scalar.",
+        "Converted to a vector of size d - 1 with",
+        "all same entries."
+      ))
     }
-    if (any(par <= 1e-12)){
-      stop(paste("The elements of par must be greater than 1e-12,",
-                 "when model = dirichlet."))
+    if (length(par) != d - 1) {
+      stop(paste(
+        "The argument par must have d - 1 elements,",
+        "when model = logistic."
+      ))
+    }
+  } else if (model == "dirichlet") {
+    if (NROW(par) != d - 1 | NCOL(par) != 2) {
+      stop(paste(
+        "The argument par must be a (d-1) x 2 ,",
+        "when model = dirichlet."
+      ))
+    }
+    if (any(par <= 1e-12)) {
+      stop(paste(
+        "The elements of par must be greater than 1e-12,",
+        "when model = dirichlet."
+      ))
     }
   }
 
   # prepare arguments ####
-  if (model == "HR"){
-    if (is.matrix(par)){
+  if (model == "HR") {
+    if (is.matrix(par)) {
       par.vec <- par[ends.mat]
     } else {
       par.vec <- par
     }
-  } else if (model == "logistic"){
+  } else if (model == "logistic") {
     theta <- par
-  } else if (model == "dirichlet"){
+  } else if (model == "dirichlet") {
     alpha.mat <- par
   }
 
@@ -355,18 +384,20 @@ rmpareto_tree <- function(n, model = c("HR", "logistic", "dirichlet")[1],
     A[[k]] <- matrix(0, nrow = d, ncol = e)
     e.start[[k]] <- e.end[[k]] <- numeric(e)
     short.paths <- igraph::shortest_paths(tree, from = k, to = 1:d)
-    for (h in 1:d){
+    for (h in 1:d) {
       path <- short.paths$vpath[[h]]
       idx.tmp <- idx.e[cbind(path[-length(path)], path[-1])]
       A[[k]][h, idx.tmp] <- 1
       e.start[[k]][idx.tmp] <-
         apply(ends.mat[idx.tmp, ] ==
-                matrix(path[-length(path)], nrow = length(idx.tmp), ncol = 2),
-              MARGIN = 1, FUN = function(x) which(x == TRUE))
+          matrix(path[-length(path)], nrow = length(idx.tmp), ncol = 2),
+        MARGIN = 1, FUN = function(x) which(x == TRUE)
+        )
       e.end[[k]][idx.tmp] <-
         apply(ends.mat[idx.tmp, ] ==
-                matrix(path[-1], nrow = length(idx.tmp), ncol = 2),
-              MARGIN = 1, FUN = function(x) which(x == TRUE))
+          matrix(path[-1], nrow = length(idx.tmp), ncol = 2),
+        MARGIN = 1, FUN = function(x) which(x == TRUE)
+        )
     }
   }
 
@@ -376,24 +407,28 @@ rmpareto_tree <- function(n, model = c("HR", "logistic", "dirichlet")[1],
   while (n.total < n) {
     counter <- counter + 1
     shift <- sample(1:d, n, replace = TRUE)
-    for (k in 1:d){
+    for (k in 1:d) {
       n.k <- sum(shift == k)
-      if (n.k > 0){
+      if (n.k > 0) {
         proc <-
           switch(model,
-                 "HR" =
-                   simu_px_tree_HR(n = n.k, Gamma_vec = par.vec, A = A[[k]]),
-                 "logistic" =
-                   simu_px_tree_logistic(n = n.k,
-                                         theta = theta, A = A[[k]]),
-                 "dirichlet" =
-                   simu_px_tree_dirichlet(n = n.k,
-                                          alpha.start =
-                                            alpha.mat[cbind(1:e, e.start[[k]])],
-                                          alpha.end =
-                                            alpha.mat[cbind(1:e, e.end[[k]])],
-                                              A = A[[k]])
-        )
+            "HR" =
+              simu_px_tree_HR(n = n.k, Gamma_vec = par.vec, A = A[[k]]),
+            "logistic" =
+              simu_px_tree_logistic(
+                n = n.k,
+                theta = theta, A = A[[k]]
+              ),
+            "dirichlet" =
+              simu_px_tree_dirichlet(
+                n = n.k,
+                alpha.start =
+                  alpha.mat[cbind(1:e, e.start[[k]])],
+                alpha.end =
+                  alpha.mat[cbind(1:e, e.end[[k]])],
+                A = A[[k]]
+              )
+          )
 
         if (any(dim(proc) != c(n.k, d))) {
           stop("The generated sample has wrong size.")
@@ -419,25 +454,23 @@ rmpareto_tree <- function(n, model = c("HR", "logistic", "dirichlet")[1],
 #' @param n Number of simulations.
 #' @param model The parametric model type; one of:
 #' \itemize{
-#' \item \code{HR} (default),
-#' \item \code{logistic},
-#' \item \code{neglogistic},
-#' \item \code{dirichlet}.
+#'   \item `HR` (default),
+#'   \item `logistic`,
+#'   \item `neglogistic`,
+#'   \item `dirichlet`.
 #' }
 #' @param d Dimension of the multivariate Pareto
 #' distribution.
-#' @param par Respective parameter for the given \code{model}, that is,
+#' @param par Respective parameter for the given `model`, that is,
 #' \itemize{
-#' \item \eqn{\Gamma}, numeric \eqn{d \times d}{d x d} variogram matrix,
-#' if \code{model = HR}.
-#' \item \eqn{\theta \in (0, 1)}{0 < \theta < 1}, if \code{model = logistic}.
-#' \item \eqn{\theta > 0}, if \code{model = neglogistic}.
-#' \item \eqn{\alpha}, numeric vector of size \code{d} with positive entries,
-#' if \code{model = dirichlet}.
+#'   \item \eGamma, numeric \dxd variogram matrix, if `model = HR`.
+#'   \item \eqn{\theta \in (0, 1)}{0 < \theta < 1}, if `model = logistic`.
+#'   \item \eqn{\theta > 0}, if `model = neglogistic`.
+#'   \item \eqn{\alpha}, numeric vector of size `d` with positive entries, if `model = dirichlet`.
 #' }
 #'
 #' @return
-#' Numeric matrix of size \eqn{n \times d}{n x d} of simulations of the
+#' Numeric \nxd matrix of simulations of the
 #' multivariate max-stable distribution.
 #'
 #' @details
@@ -450,10 +483,12 @@ rmpareto_tree <- function(n, model = c("HR", "logistic", "dirichlet")[1],
 #' ## A 4-dimensional HR distribution
 #' n <- 10
 #' d <- 4
-#' G <-  cbind(c(0, 1.5, 1.5, 2),
-#'             c(1.5, 0, 2, 1.5),
-#'             c(1.5, 2, 0, 1.5),
-#'             c(2, 1.5, 1.5, 0))
+#' G <- cbind(
+#'   c(0, 1.5, 1.5, 2),
+#'   c(1.5, 0, 2, 1.5),
+#'   c(1.5, 2, 0, 1.5),
+#'   c(2, 1.5, 1.5, 0)
+#' )
 #'
 #' rmstable(n, "HR", d = d, par = G)
 #'
@@ -474,7 +509,6 @@ rmpareto_tree <- function(n, model = c("HR", "logistic", "dirichlet")[1],
 #' d <- 4
 #' alpha <- c(.8, 1, .5, 2)
 #' rmstable(n, "dirichlet", d, par = alpha)
-#'
 #' @references
 #'  \insertAllCited{}
 #'
@@ -487,50 +521,57 @@ rmstable <- function(n,
   model_nms <- c("HR", "logistic", "neglogistic", "dirichlet")
 
   # check arguments ####
-  if (d != round(d) | d < 1){
+  if (d != round(d) | d < 1) {
     stop("The argument d must be a positive integer.")
   }
 
-  if (n != round(n) | n < 1){
+  if (n != round(n) | n < 1) {
     stop("The argument n must be a positive integer.")
   }
 
-  if (!(model %in% model_nms)){
-    stop(paste("The model must be one of", model_nms))
+  if (!(model %in% model_nms)) {
+    stop(paste("The model must be one of ", paste(model_nms, collapse = ", "),
+      ".",
+      sep = ""
+    ))
   }
 
   if (model == "HR") {
-    if (!is.matrix(par)){
+    if (!is.matrix(par)) {
       stop("The argument par must be a matrix, when model = HR.")
     }
 
-    if (NROW(par) != d | NCOL(par) != d){
+    if (NROW(par) != d | NCOL(par) != d) {
       stop("The argument par must be a d x d matrix, when model = HR.")
     }
-
   } else if (model == "logistic") {
-    if (length(par) != 1 | par <= 1e-12 | par >= 1 - 1e-12){
-      stop(paste("The argument par must be scalar between 1e-12 and 1 - 1e-12,",
-                 "when model = logistic."))
+    if (length(par) != 1 | par <= 1e-12 | par >= 1 - 1e-12) {
+      stop(paste(
+        "The argument par must be scalar between 1e-12 and 1 - 1e-12,",
+        "when model = logistic."
+      ))
     }
-
   } else if (model == "neglogistic") {
-    if (par <= 1e-12){
-      stop(paste("The argument par must be scalar greater than 1e-12,",
-                 "when model = neglogistic."))
+    if (par <= 1e-12) {
+      stop(paste(
+        "The argument par must be scalar greater than 1e-12,",
+        "when model = neglogistic."
+      ))
     }
-
   } else if (model == "dirichlet") {
-    if (length(par) != d){
-      stop(paste("The argument par must be a vector with d elements,",
-                 "when model = dirichlet."))
+    if (length(par) != d) {
+      stop(paste(
+        "The argument par must be a vector with d elements,",
+        "when model = dirichlet."
+      ))
     }
 
-    if (any(par <= 1e-12)){
-      stop(paste("The elements of par must be greater than 1e-12,",
-                 "when model = dirichlet."))
+    if (any(par <= 1e-12)) {
+      stop(paste(
+        "The elements of par must be greater than 1e-12,",
+        "when model = dirichlet."
+      ))
     }
-
   }
 
   # prepare arguments ####
@@ -541,30 +582,30 @@ rmstable <- function(n,
     cov.mat <- Gamma2Sigma(Gamma, k = 1, full = FALSE)
     chol_mat <- matrix(0, d, d)
 
-    result <- tryCatch({
-      chol_mat[-1, -1] <- chol(cov.mat)
-    },
-    error = function(e) {
-      stop(paste("The covariance matrix associated to Gamma",
-                 "cannot be factorized with Cholesky."))
-    })
+    result <- tryCatch(
+      {
+        chol_mat[-1, -1] <- chol(cov.mat)
+      },
+      error = function(e) {
+        stop(paste(
+          "The covariance matrix associated to Gamma",
+          "cannot be factorized with Cholesky."
+        ))
+      }
+    )
 
     # compute trend (matrix where each row is one variable)
-    trend <- t(sapply(1:d, function(k){
-      sapply(1:d, function(j){
+    trend <- t(sapply(1:d, function(k) {
+      sapply(1:d, function(j) {
         Gamma[j, k] / 2
-      }
-      )}))
-
+      })
+    }))
   } else if (model == "logistic") {
     theta <- par
-
   } else if (model == "neglogistic") {
     theta <- par
-
   } else if (model == "dirichlet") {
     alpha <- par
-
   }
 
   # function body ####
@@ -580,15 +621,18 @@ rmstable <- function(n,
       counter[ind] <- counter[ind] + 1
       proc <-
         switch(model,
-               "HR" =
-                 simu_px_HR(n = n.ind, idx = k, d = d, trend = trend[k, ],
-                            chol_mat = chol_mat),
-               "logistic" =
-                 simu_px_logistic(n = n.ind, idx = k, d = d, theta = theta),
-               "neglogistic" =
-                 simu_px_neglogistic(n = n.ind, idx = k, d = d, theta = theta),
-               "dirichlet" =
-                 simu_px_dirichlet(n = n.ind, idx = k, d = d, alpha = alpha))
+          "HR" =
+            simu_px_HR(
+              n = n.ind, idx = k, d = d, trend = trend[k, ],
+              chol_mat = chol_mat
+            ),
+          "logistic" =
+            simu_px_logistic(n = n.ind, idx = k, d = d, theta = theta),
+          "neglogistic" =
+            simu_px_neglogistic(n = n.ind, idx = k, d = d, theta = theta),
+          "dirichlet" =
+            simu_px_dirichlet(n = n.ind, idx = k, d = d, alpha = alpha)
+        )
 
       if (any(dim(proc) != c(n.ind, d))) {
         stop("The generated sample has wrong size.")
@@ -597,14 +641,15 @@ rmstable <- function(n,
       if (k == 1) {
         ind.upd <- rep(TRUE, times = n.ind)
       } else {
-        ind.upd <- sapply(1:n.ind, function(i)
+        ind.upd <- sapply(1:n.ind, function(i) {
           all(1 / poisson[idx[i]] * proc[i, 1:(k - 1)] <=
-                res[idx[i], 1:(k - 1)]))
+            res[idx[i], 1:(k - 1)])
+        })
       }
       if (any(ind.upd)) {
         idx.upd <- idx[ind.upd]
         res[idx.upd, ] <- pmax(res[idx.upd, ], 1 / poisson[idx.upd] *
-                                 proc[ind.upd, ])
+          proc[ind.upd, ])
       }
       poisson[ind] <- poisson[ind] + stats::rexp(n.ind)
     }
@@ -623,30 +668,30 @@ rmstable <- function(n,
 #' @param n Number of simulations.
 #' @param model The parametric model type; one of:
 #' \itemize{
-#' \item \code{HR} (default),
-#' \item \code{logistic},
-#' \item \code{dirichlet}.
+#'   \item `HR` (default),
+#'   \item `logistic`,
+#'   \item `dirichlet`.
 #' }
-#' @param tree Graph object from \code{igraph} package.
+#' @param tree Graph object from `igraph` package.
 #' This object must be a tree, i.e., an
 #' undirected graph that is connected and has no cycles.
-#' @param par Respective parameter for the given \code{model}, that is,
+#' @param par Respective parameter for the given `model`, that is,
 #' \itemize{
-#' \item \eqn{\Gamma}, numeric \eqn{d \times d}{d x d} variogram matrix,
-#' where only the entries corresponding to the edges of the \code{tree} are used,
-#' if \code{model = HR}. Alternatively, can be a vector of
-#' length \eqn{d - 1} containing the entries of the variogram corresponding
-#' to the edges of the given \code{tree}.
-#' \item \eqn{\theta \in (0, 1)}{0 < \theta < 1}, vector of length \eqn{d - 1}
-#' containing the logistic parameters corresponding
-#' to the edges of the given \code{tree}, if \code{model = logistic}.
-#' \item a matrix of size \eqn{(d - 1) \times 2}{(d - 1) x 2}, where the rows
-#' contain the parameter vectors \eqn{\alpha} of size 2 with positve entries
-#' for each of the edges in \code{tree}, if \code{model = dirichlet}.
+#'   \item \eGamma, numeric \dxd variogram matrix,
+#'     where only the entries corresponding to the edges of the `tree` are used,
+#'     if `model = HR`. Alternatively, can be a vector of
+#'     length `d-1` containing the entries of the variogram corresponding
+#'     to the edges of the given `tree`.
+#'   \item \eqn{\theta \in (0, 1)}{0 < \theta < 1}, vector of length `d-1`
+#'     containing the logistic parameters corresponding
+#'     to the edges of the given `tree`, if `model = logistic`.
+#'   \item a matrix of size \eqn{(d - 1) \times 2}{(d - 1) x 2}, where the rows
+#'     contain the parameter vectors \eqn{\alpha} of size 2 with positve entries
+#'     for each of the edges in `tree`, if `model = dirichlet`.
 #' }
 #'
 #' @return
-#' Numeric matrix of size \eqn{n \times d}{n x d} of simulations of the
+#' Numeric \nxd matrix of simulations of the
 #' multivariate max-stable distribution.
 #'
 #' @details
@@ -660,20 +705,21 @@ rmstable <- function(n,
 #' ## A 4-dimensional HR tree model
 #'
 #' my_tree <- igraph::graph_from_adjacency_matrix(rbind(
-#' c(0, 1, 0, 0),
-#' c(1, 0, 1, 1),
-#' c(0, 1, 0, 0),
-#' c(0, 1, 0, 0)),
-#' mode = "undirected")
+#'   c(0, 1, 0, 0),
+#'   c(1, 0, 1, 1),
+#'   c(0, 1, 0, 0),
+#'   c(0, 1, 0, 0)
+#' ),
+#' mode = "undirected"
+#' )
 #' n <- 10
-#' Gamma_vec <- c(.5,1.4,.8)
+#' Gamma_vec <- c(.5, 1.4, .8)
 #' rmstable_tree(n, "HR", tree = my_tree, par = Gamma_vec)
 #'
 #' ## A 4-dimensional Dirichlet model with asymmetric edge distributions
 #'
-#' alpha = cbind(c(.2, 1, .5), c(1.5, .6, .8))
+#' alpha <- cbind(c(.2, 1, .5), c(1.5, .6, .8))
 #' rmstable_tree(n, model = "dirichlet", tree = my_tree, par = alpha)
-#'
 #' @references
 #'  \insertAllCited{}
 #'
@@ -686,7 +732,7 @@ rmstable_tree <- function(n, model = c("HR", "logistic", "dirichlet")[1],
 
   # graph theory objects ####
   # check if it is directed
-  if (igraph::is_directed(tree)){
+  if (igraph::is_directed(tree)) {
     warning("The given tree is directed. Converted to undirected.")
     tree <- igraph::as.undirected(tree)
   }
@@ -701,63 +747,91 @@ rmstable_tree <- function(n, model = c("HR", "logistic", "dirichlet")[1],
   is_connected <- igraph::is_connected(tree)
   is_tree <- is_connected & (e == d - 1)
 
-  if (!is_tree){
+  if (!is_tree) {
     stop("The given graph is not a tree.")
   }
 
 
   # check arguments ####
-  if (d != round(d) | d < 1){
+  if (d != round(d) | d < 1) {
     stop("The argument d must be a positive integer.")
   }
 
-  if (n != round(n) | n < 1){
+  if (n != round(n) | n < 1) {
     stop("The argument n must be a positive integer.")
   }
 
-  if (!(model %in% model_nms)){
-    stop(paste("The model must be one of", model_nms))
+  if (!(model %in% model_nms)) {
+    stop(paste("The model must be one of ", paste(model_nms, collapse = ", "),
+      ".",
+      sep = ""
+    ))
   }
 
   if (model == "HR") {
-    if (!is.matrix(par)){
-      if (length(par) != (d - 1)){
-        stop(paste("The argument par must be a d x d matrix,",
-                   "or a vector with d - 1 elements, when model = HR."))
+    if (!is.matrix(par)) {
+      if (length(par) != (d - 1)) {
+        stop(paste(
+          "The argument par must be a d x d matrix,",
+          "or a vector with d - 1 elements, when model = HR."
+        ))
       }
     } else {
-      if (NROW(par) != d | NCOL(par) != d){
-        stop(paste("The argument par must be a d x d matrix,",
-                   "or a vector with d elements, when model = HR."))
+      if (NROW(par) != d | NCOL(par) != d) {
+        stop(paste(
+          "The argument par must be a d x d matrix,",
+          "or a vector with d elements, when model = HR."
+        ))
       }
     }
   } else if (model == "logistic") {
-    if (length(par) != 1 | par <= 1e-12 | par >= 1 - 1e-12){
-      stop(paste("The argument par must be scalar between 1e-12 and 1 - 1e-12,",
-                 "when model = logistic."))
+    if (any(par <= 1e-12) | any(par >= 1 - 1e-12)) {
+      stop(paste(
+        "The elements of par must be",
+        "between 1e-12 and 1 - 1e-12,",
+        "when model = logistic."
+      ))
     }
 
-  } else if (model == "dirichlet") {
-    if (NROW(par) != d - 1 | NCOL(par) != 2){
-      stop(paste("The argument par must be a (d-1) x 2 ,",
-                 "when model = dirichlet."))
+    if (length(par) == 1) {
+      par <- rep(par, d - 1)
+      warning(paste(
+        "The argument par was a scalar.",
+        "Converted to a vector of size d - 1 with",
+        "all same entries."
+      ))
     }
-    if (any(par <= 1e-12)){
-      stop(paste("The elements of par must be greater than 1e-12,",
-                 "when model = dirichlet."))
+    if (length(par) != d - 1) {
+      stop(paste(
+        "The argument par must have d - 1 elements,",
+        "when model = logistic."
+      ))
+    }
+  } else if (model == "dirichlet") {
+    if (NROW(par) != d - 1 | NCOL(par) != 2) {
+      stop(paste(
+        "The argument par must be a (d-1) x 2 ,",
+        "when model = dirichlet."
+      ))
+    }
+    if (any(par <= 1e-12)) {
+      stop(paste(
+        "The elements of par must be greater than 1e-12,",
+        "when model = dirichlet."
+      ))
     }
   }
 
   # prepare arguments ####
-  if (model == "HR"){
-    if (is.matrix(par)){
+  if (model == "HR") {
+    if (is.matrix(par)) {
       par.vec <- par[ends.mat]
     } else {
       par.vec <- par
     }
-  } else if (model == "logistic"){
+  } else if (model == "logistic") {
     theta <- par
-  } else if (model == "dirichlet"){
+  } else if (model == "dirichlet") {
     alpha.mat <- par
   }
 
@@ -774,18 +848,20 @@ rmstable_tree <- function(n, model = c("HR", "logistic", "dirichlet")[1],
     A[[k]] <- matrix(0, nrow = d, ncol = e)
     e.start[[k]] <- e.end[[k]] <- numeric(e)
     short.paths <- igraph::shortest_paths(tree, from = k, to = 1:d)
-    for (h in 1:d){
-      path <-  short.paths$vpath[[h]]
+    for (h in 1:d) {
+      path <- short.paths$vpath[[h]]
       idx.tmp <- idx.e[cbind(path[-length(path)], path[-1])]
       A[[k]][h, idx.tmp] <- 1
       e.start[[k]][idx.tmp] <-
         apply(ends.mat[idx.tmp, ] ==
-                matrix(path[-length(path)], nrow = length(idx.tmp), ncol = 2),
-              MARGIN = 1, FUN = function(x) which(x == TRUE))
+          matrix(path[-length(path)], nrow = length(idx.tmp), ncol = 2),
+        MARGIN = 1, FUN = function(x) which(x == TRUE)
+        )
       e.end[[k]][idx.tmp] <-
         apply(ends.mat[idx.tmp, ] ==
-                matrix(path[-1], nrow = length(idx.tmp), ncol = 2),
-              MARGIN = 1, FUN = function(x) which(x == TRUE))
+          matrix(path[-1], nrow = length(idx.tmp), ncol = 2),
+        MARGIN = 1, FUN = function(x) which(x == TRUE)
+        )
     }
   }
 
@@ -802,19 +878,23 @@ rmstable_tree <- function(n, model = c("HR", "logistic", "dirichlet")[1],
       counter[ind] <- counter[ind] + 1
       proc <-
         switch(model,
-               "HR" =
-                 simu_px_tree_HR(n = n.ind, Gamma_vec = par.vec, A = A[[k]]),
-               "logistic" =
-                 simu_px_tree_logistic(n = n.ind,
-                                       theta = theta, A = A[[k]]),
-               "dirichlet" =
-                 simu_px_tree_dirichlet(n = n.ind,
-                                        alpha.start =
-                                          alpha.mat[cbind(1:e, e.start[[k]])],
-                                        alpha.end =
-                                          alpha.mat[cbind(1:e, e.end[[k]])],
-                                        A = A[[k]])
-      )
+          "HR" =
+            simu_px_tree_HR(n = n.ind, Gamma_vec = par.vec, A = A[[k]]),
+          "logistic" =
+            simu_px_tree_logistic(
+              n = n.ind,
+              theta = theta, A = A[[k]]
+            ),
+          "dirichlet" =
+            simu_px_tree_dirichlet(
+              n = n.ind,
+              alpha.start =
+                alpha.mat[cbind(1:e, e.start[[k]])],
+              alpha.end =
+                alpha.mat[cbind(1:e, e.end[[k]])],
+              A = A[[k]]
+            )
+        )
 
       if (any(dim(proc) != c(n.ind, d))) {
         stop("The generated sample has wrong size.")
@@ -823,14 +903,15 @@ rmstable_tree <- function(n, model = c("HR", "logistic", "dirichlet")[1],
       if (k == 1) {
         ind.upd <- rep(TRUE, times = n.ind)
       } else {
-        ind.upd <- sapply(1:n.ind, function(i)
+        ind.upd <- sapply(1:n.ind, function(i) {
           all(1 / poisson[idx[i]] * proc[i, 1:(k - 1)] <=
-                res[idx[i], 1:(k - 1)]))
+            res[idx[i], 1:(k - 1)])
+        })
       }
       if (any(ind.upd)) {
         idx.upd <- idx[ind.upd]
         res[idx.upd, ] <- pmax(res[idx.upd, ], 1 / poisson[idx.upd] *
-                                proc[ind.upd, ])
+          proc[ind.upd, ])
       }
       poisson[ind] <- poisson[ind] + stats::rexp(n.ind)
     }
